Pylibinjection
==============

Pylibinjection is a wrapper for the Libinjection library (https://github.com/client9/libinjection).


Requirements
------------

* Python 2.5 or later
* gcc
* Libinjection


Installation
------------

::

    $ cd /opt
    $ sudo git clone https://github.com/client9/libinjection.git
    $ sudo git clone https://github.com/glastopf/pylibinjection.git
    $ cd pylibinjection/
    $ sudo python setup.py build
    $ sudo python setup.py install

Usage
-----

::

    $ python
    >>> import pylibinjection
    >>> pylibinjection.detect_sqli("admin;--")

License information
-------------------

Copyright (C) 2013 Angelo Dell'Aera <buffer@antifork.org>

License: GNU General Public License, version 2 or later; see COPYING.txt included in this archive for details.
